@@ -39,8 +39,7 @@
  * @{
  */
 /*----------------------------------------------------------------------------*/
-#ifndef _DNSSEC_RSA_H
-#define	_DNSSEC_RSA_H
+#pragma once
 /*------------------------------------------------------------------------------
  *
  * USE INCLUDES */
@@ -64,6 +63,4 @@ void dnskey_rsa_parse_init(dnskey_field_parser *fp);
 }
 #endif
 
-#endif	/* _DNSSEC_RSA_H */
-
 /** @} */
