@@ -115,7 +115,7 @@ dns_resource_record_set_record(dns_resource_record *rr, const u8* fqdn, u16 rtyp
                 // do the computations into 32 bits words
 
                 u32 rdata_size_32 = rr->rdata_size;
-                u32 buffer_size_32 = MIN((rdata_size_32 + 15) & 0xfff0, 0xffff);
+                u32 buffer_size_32 = MIN(((rdata_size_32 + 15) & ~15), 0xffff);
 #if DEBUG
                 if(rr->rdata != NULL)
                 {
@@ -409,7 +409,6 @@ static const u8* dns_resource_record_view_get_rdata(void *data, const void *rr_)
     return rr->rdata;
 }
 
-/// @todo 20190820 edf -- replace the malloc by a zalloc, check for usage first.
 static void *dns_resource_record_view_new_instance(void *data, const u8 *fqdn, u16 rtype, u16 rclass, s32 ttl, u16 rdata_size, const u8 *rdata)
 {
     (void)data;
