@@ -54,6 +54,11 @@
 extern logger_handle *g_system_logger;
 #define MODULE_MSG_HANDLE g_system_logger
 
+#if DNSCORE_HAS_MALLOC_DEBUG_SUPPORT
+void debug_malloc_mutex_lock();     // Internal use only
+void debug_malloc_mutex_unlock();   // Internal use only
+#endif
+
 /*------------------------------------------------------------------------------
  * STATIC PROTOTYPES */
 
@@ -65,7 +70,7 @@ pid_t g_pid = -1;
 pid_t
 fork_ex()
 {
-#ifndef WIN32
+#if __unix__
     logger_flush();
     dnscore_stop_timer();
     service_stop_all();
@@ -74,8 +79,18 @@ fork_ex()
 #if MUTEX_CONTENTION_MONITOR
     mutex_contention_monitor_stop();
 #endif
+
+#if DNSCORE_HAS_MALLOC_DEBUG_SUPPORT
+    // ensure this mutex isn't locked while we are forking
+    debug_malloc_mutex_lock();
+#endif
+
     pid_t pid = fork();
-    
+
+#if DNSCORE_HAS_MALLOC_DEBUG_SUPPORT
+    debug_malloc_mutex_unlock();
+#endif
+
     if(pid == 0)
     {
         g_pid = getpid();
@@ -100,7 +115,7 @@ waitpid_ex(pid_t pid, int *wstatus, int options)
 {
     int ret;
 
-#ifndef WIN32
+#if __unix__
     
     while((ret = waitpid(pid, wstatus, options)) < 0)
     {
