@@ -48,8 +48,6 @@
 #include <stdlib.h>
 
 #include <arpa/inet.h>
-#include <openssl/sha.h>
-#include <openssl/engine.h>
 
 #include <dnscore/sys_types.h>
 #include <dnscore/logger.h>
@@ -70,7 +68,6 @@
 
 #include "dnsdb/nsec.h"
 
-
 #define MODULE_MSG_HANDLE g_dnssec_logger
 
 /*
