@@ -383,7 +383,7 @@ static void server_rw_set_cpu_affinity(int index, int w0s1)
         cpuset_set((cpuid_t)affinity_with, mycpu);
         if(pthread_setaffinity_np(thread_self(), cpuset_size(mycpu), mycpu) != 0)
         {
-#pragma message("TODO: report errors")
+#pragma message("TODO: report errors") // NetBSD
         }
         cpuset_destroy(mycpu);
     }
@@ -391,13 +391,16 @@ static void server_rw_set_cpu_affinity(int index, int w0s1)
     {
     }
 #elif defined(WIN32)
-#pragma message("TODO: implement")
+#pragma message("TODO: implement") // WIN32
 #else
     cpu_set_t mycpu;
     CPU_ZERO(&mycpu);
     CPU_SET(affinity_with, &mycpu);
     pthread_setaffinity_np(thread_self(), sizeof(cpu_set_t), &mycpu);
 #endif
+#else
+    (void)index;
+    (void)w0s1;
 #endif
 }
 
@@ -1300,7 +1303,7 @@ server_rw_query_loop(struct service_worker_s *worker)
 
                         debug_bench_logdump_all();
 #endif
-#if HAS_LIBC_MALLOC_DEBUG_SUPPORT
+#if DNSCORE_HAS_LIBC_MALLOC_DEBUG_SUPPORT
                         debug_malloc_hook_caller_dump();
 #endif
                     }
