@@ -319,7 +319,7 @@ static void server_sm_set_cpu_affinity(int index)
         cpuset_set((cpuid_t)affinity_with, mycpu);
         if(pthread_setaffinity_np(thread_self(), cpuset_size(mycpu), mycpu) != 0)
         {
-#pragma message("TODO: report errors")
+#pragma message("TODO: report errors") // NetBSD
         }
         cpuset_destroy(mycpu);
     }
@@ -327,13 +327,15 @@ static void server_sm_set_cpu_affinity(int index)
     {
     }
 #elif defined(WIN32)
-#pragma message("TODO: implement")
+#pragma message("TODO: implement") // WIN32
 #else
     cpu_set_t mycpu;
     CPU_ZERO(&mycpu);
     CPU_SET(affinity_with, &mycpu);
     pthread_setaffinity_np(thread_self(), sizeof(cpu_set_t), &mycpu);
 #endif
+#else
+    (void)index;
 #endif
 }
 
@@ -428,8 +430,11 @@ server_sm_udp_worker_thread(void *parms)
                 {
                     //  ignore
 #if DEBUG
-                    log_debug("server_sm_udp_worker_thread: good-dropped %d bytes from %{sockaddr}", message_get_size(mesg), message_get_sender_sa(mesg));
-                    message_log(MODULE_MSG_HANDLE, LOG_INFO, mesg);
+                    if(message_get_size(mesg) > 0)
+                    {
+                        log_debug("server_sm_udp_worker_thread: good-dropped %d bytes from %{sockaddr}", message_get_size(mesg), message_get_sender_sa(mesg));
+                        message_log(MODULE_MSG_HANDLE, LOG_INFO, mesg);
+                    }
 #endif
                 }
                 else if(ret == STOPPED_BY_APPLICATION_SHUTDOWN)
@@ -815,7 +820,7 @@ server_sm_query_loop(struct service_worker_s *worker)
 
                         debug_bench_logdump_all();
 #endif
-#if HAS_LIBC_MALLOC_DEBUG_SUPPORT
+#if DNSCORE_HAS_LIBC_MALLOC_DEBUG_SUPPORT
                         debug_malloc_hook_caller_dump();
 #endif
                     }
