@@ -454,8 +454,12 @@ parse_private_key_record(struct dnskey_private_inputs_s *input)
             formatln("tag mismatch '%s': expected %hu, got %hu", input->file_text, input->tag, tag);
             osformatln(termerr, "tag mismatch '%s': expected %hu, got %hu", input->file_text, input->tag, tag);
             ret = INVALID_STATE_ERROR;
+            return;
         }
 
+        key->vtbl->dnssec_key_print_fields(key, termout);
+        flushout();
+
         ptr_vector rrset;
         ptr_vector_init_empty(&rrset);
 
@@ -499,6 +503,7 @@ parse_private_key_record(struct dnskey_private_inputs_s *input)
         {
             rdata_desc rrsig_desc = { rrsig_rr->tctr.qtype, rrsig_rr->rdata_size, rrsig_rr->rdata };
             formatln("signature: %{typerdatadesc}", &rrsig_desc);
+            flushout();
 
             dnskey_signature ds_back;
             dnskey_signature_init(&ds_back);
@@ -507,11 +512,10 @@ parse_private_key_record(struct dnskey_private_inputs_s *input)
             dnskey_signature_set_rrset_reference(&ds_back, &rrset);
             dnskey_signature_set_canonised(&ds_back, FALSE);
             ret = dnskey_signature_sign(&ds_back, key, (void **) &rrsig_rr);
+            ya_result ret_verify = dnskey_signature_verify(&ds_back, key, rrsig_rr);
             dnskey_signature_finalize(&ds_back);
 
-            ret = dnskey_signature_verify(&ds_back, key, rrsig_rr);
-
-            if(ISOK(ret))
+            if(ISOK(ret_verify))
             {
                 println("signature verified");
             }
@@ -527,13 +531,12 @@ parse_private_key_record(struct dnskey_private_inputs_s *input)
             dnskey_signature_set_rrset_reference(&ds_other, &rrset_different);
             dnskey_signature_set_canonised(&ds_other, FALSE);
             ret = dnskey_signature_sign(&ds_other, key, (void **) &rrsig_rr);
+            ret_verify = dnskey_signature_verify(&ds_other, key, rrsig_rr);
             dnskey_signature_finalize(&ds_other);
 
-            ret = dnskey_signature_verify(&ds_other, key, rrsig_rr);
-
-            if(FAIL(ret))
+            if(FAIL(ret_verify))
             {
-                println("signature not verified as it should");
+                println("signature not verified (as it should)");
                 ret = SUCCESS;
             }
             else
